==> sigPathway_1.18.0.zip: sigPathway/doc/sigPathway-vignette.R <==
###################################################
### chunk number 1: 
###################################################
#line 120 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpMvBeOg/R.INSTALL38d25000/sigPathway/inst/doc/sigPathway-vignette.Rnw"
library(sigPathway)
data(MuscleExample)
ls()



###################################################
### chunk number 2: 
###################################################
#line 137 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpMvBeOg/R.INSTALL38d25000/sigPathway/inst/doc/sigPathway-vignette.Rnw"
dim(tab)
print(tab[501:504, 1:3])
table(phenotype)



###################################################
### chunk number 3: PSIDhist
###################################################
#line 150 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpMvBeOg/R.INSTALL38d25000/sigPathway/inst/doc/sigPathway-vignette.Rnw"
statList <- calcTStatFast(tab, phenotype, ngroups = 2)
hist(statList$pval, breaks = seq(0,1,0.025), xlab = "p-value",
     ylab = "Frequency", main = "")


###################################################
### chunk number 4: 
###################################################
#line 165 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpMvBeOg/R.INSTALL38d25000/sigPathway/inst/doc/sigPathway-vignette.Rnw"
set.seed(1234)
res.muscle <-
  runSigPathway(G, 20, 500, tab, phenotype, nsim = 1000,
                weightType = "constant", ngroups = 2, npath = 25, 
                verbose = FALSE, allpathways = FALSE, annotpkg = "hgu133a.db",
                alwaysUseRandomPerm = FALSE)


###################################################
### chunk number 5: 
###################################################
#line 227 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpMvBeOg/R.INSTALL38d25000/sigPathway/inst/doc/sigPathway-vignette.Rnw"
print(res.muscle$df.pathways[1:10, ])


###################################################
### chunk number 6: 
###################################################
#line 244 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpMvBeOg/R.INSTALL38d25000/sigPathway/inst/doc/sigPathway-vignette.Rnw"
print(res.muscle$list.gPS[[7]][1:10, ])


###################################################
### chunk number 7: 
###################################################
#line 281 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpMvBeOg/R.INSTALL38d25000/sigPathway/inst/doc/sigPathway-vignette.Rnw"
print(sessionInfo())

==> sigPathway_1.20.0.zip: sigPathway/doc/sigPathway-vignette.R <==
###################################################
### chunk number 1: 
###################################################
#line 120 "sigPathway-vignette.Rnw"
library(sigPathway)
data(MuscleExample)
ls()



###################################################
### chunk number 2: 
###################################################
#line 137 "sigPathway-vignette.Rnw"
dim(tab)
print(tab[501:504, 1:3])
table(phenotype)



###################################################
### chunk number 3: PSIDhist
###################################################
#line 150 "sigPathway-vignette.Rnw"
statList <- calcTStatFast(tab, phenotype, ngroups = 2)
hist(statList$pval, breaks = seq(0,1,0.025), xlab = "p-value",
     ylab = "Frequency", main = "")


###################################################
### chunk number 4: 
###################################################
#line 165 "sigPathway-vignette.Rnw"
set.seed(1234)
res.muscle <-
  runSigPathway(G, 20, 500, tab, phenotype, nsim = 1000,
                weightType = "constant", ngroups = 2, npath = 25, 
                verbose = FALSE, allpathways = FALSE, annotpkg = "hgu133a.db",
                alwaysUseRandomPerm = FALSE)


###################################################
### chunk number 5: 
###################################################
#line 227 "sigPathway-vignette.Rnw"
print(res.muscle$df.pathways[1:10, ])


###################################################
### chunk number 6: 
###################################################
#line 244 "sigPathway-vignette.Rnw"
print(res.muscle$list.gPS[[7]][1:10, ])


###################################################
### chunk number 7: 
###################################################
#line 281 "sigPathway-vignette.Rnw"
print(sessionInfo())
